@@ -1,7 +1,10 @@
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Title.pm 67466 2008-07-30T01:53:50.528367Z daisuke  $
 
 package Google::Chart::Title;
 use Moose;
-use namespace::clean -except => qw(meta);
+use Google::Chart::Types;
+
+with 'Google::Chart::QueryComponent';
 
 has 'text' => (
     is => 'rw',
@@ -19,10 +22,14 @@ has 'fontsize' => (
     isa => 'Num'
 );
 
+__PACKAGE__->meta->make_immutable;
+
+no Moose;
+
 sub as_query {
     my $self = shift;
 
-    my $text = $self->text;
+    my $text = $self->title;
     $text =~ s/\r?\n/|/gsm;
     my %data = (
         chtt => $text
@@ -37,11 +44,10 @@ sub as_query {
         );
     }
 
-    return %data;
+    return wantarray ? %data : 
+        join('&', map { "$_=$data{$_}" } keys %data );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -54,4 +60,4 @@ Google::Chart::Title - Apply Title
 
 =head2 as_query
 
-=cut
+=cut
\ No newline at end of file
